crystal_toolkit.components.transformations.grainboundary module — Crystal Toolkit documentation

# crystal_toolkit.components.transformations.grainboundary module

class crystal_toolkit.components.transformations.grainboundary.GrainBoundaryTransformationComponent(input_structure_component_id: str, *args, **kwargs)

  Bases: `TransformationComponent`

  property description
  generate_callbacks(app, cache)

    Generate all callbacks associated with the layouts in this app. Assume that “suppress_callback_exceptions” is True, since it is not always guaranteed that all layouts will be displayed to the end user at all times, but it’s important the callbacks are defined on the server.

  options_layouts(state=None, structure=None)

    Return a layout to change the transformation options (that is, that controls the args and kwargs that will be passed to pymatgen).

    The “state” option is so that the controls can be populated appropriately using existing args and kwargs, e.g. when restoring the control panel from a previous state.

    Parameters

      state – existing state in format {“args”: [], “kwargs”: {}}

    Returns

  property title
  property transformation